@@ -89,7 +89,7 @@ setMethod(".gdroplist",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow(visible=TRUE)
-              add(container, obj)
+              add(container, obj,...)
             }
             
             if (!is.null(handler)) {
