@@ -25,7 +25,7 @@ setMethod(".gspinbutton",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow(visible=TRUE)
-              add(container, obj)
+              add(container, obj,...)
             }
             
             if (!is.null(handler))  {
