@@ -94,7 +94,7 @@ setMethod(".gtext",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow(visible=TRUE)
-              add(container, obj)
+              add(container, obj,...)
             }
             
             if (!is.null(handler)) {
